@@ -7,6 +7,7 @@
 
 struct imapc_client_connection {
 	struct imapc_connection *conn;
+	struct imapc_client *client;
 	struct imapc_client_mailbox *box;
 };
 
@@ -23,9 +24,14 @@ struct imapc_client {
 	imapc_state_change_callback_t *state_change_callback;
 	void *state_change_context;
 
+	imapc_command_callback_t *login_callback;
+	void *login_context;
+
 	ARRAY(struct imapc_client_connection *) conns;
+	bool logging_out;
 
 	struct ioloop *ioloop;
+	bool stop_on_state_finish;
 };
 
 struct imapc_client_mailbox {
@@ -44,10 +50,13 @@ struct imapc_client_mailbox {
 	bool closing;
 };
 
+extern unsigned int imapc_client_cmd_tag_counter;
+
 void imapc_client_ref(struct imapc_client *client);
 void imapc_client_unref(struct imapc_client **client);
 
 void imapc_command_set_mailbox(struct imapc_command *cmd,
 			       struct imapc_client_mailbox *box);
+void imapc_client_try_stop(struct imapc_client *client);
 
 #endif
